Changelog
=========

Changes for the upcoming release can be found in the `"changelog.d" directory <https://github.com/python-mario/mario/tree/master/changelog.d>`_ in our repository.

..
   Do *NOT* add changelog entries here!

   This changelog is managed by towncrier and is compiled at release time.

   See https://www.python-mario.readthedocs.org/en/latest/contributing.html#changelog for details.

.. towncrier release notes start

0.0.152 (2019-08-06)
--------------------


Backward-incompatible Changes
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

- Remove read-csv-dicts --no-header option.
  `#193 <https://github.com/python-mario/mario/issues/193>`_


----


0.0.151 (2019-08-04)
--------------------


No significant changes.


----


0.0.150 (2019-08-03)
--------------------


No significant changes.


----


0.0.149 (2019-08-03)
--------------------


No significant changes.


----


0.0.148 (2019-08-03)
--------------------


Changes
^^^^^^^

- Add read-yaml-array command.
  `#172 <https://github.com/python-mario/mario/issues/172>`_


----


0.0.147 (2019-08-02)
--------------------


Changes
^^^^^^^

- Add read-json-array command.
  `#170 <https://github.com/python-mario/mario/issues/170>`_


----


0.0.146 (2019-08-02)
--------------------


Changes
^^^^^^^

- Versions of all dependencies are pinned to avoid accidental breakages from upstream changes.
  `#167 <https://github.com/python-mario/mario/issues/167>`_


----


0.0.145 (2019-08-01)
--------------------


No significant changes.


----


0.0.144 (2019-07-30)
--------------------


No significant changes.


----


0.0.143 (2019-07-30)
--------------------

Changes
^^^^^^^

- Add read and write commands for csv, toml, json, xml, yaml.


----


0.1.0 (2019-07-15)
------------------

Changes
^^^^^^^

- First release on PyPI.

---
